<?php

namespace Drupal\printjs\Plugin\views\area;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\area\TokenizeAreaPluginBase;

/**
 * Views area handler for a Printjs button.
 *
 * @ingroup views_area_handlers
 *
 * @ViewsArea("printjs_views_btn")
 */
class PrintjsViewsBtn extends TokenizeAreaPluginBase {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['printjs_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom id div for print content'),
      '#description' => $this->t('By default it will take #print, but you can custom id') . $this->t('View more <a href="@exemple">printjs.crabbly.com</a>', ['@exemple' => 'https://printjs.crabbly.com/']),
      '#default_value' => $this->options['printjs_id'],
    ];
    $form['printText'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button text'),
      '#required' => TRUE,
      '#default_value' => $this->options['printText'],
    ];

    $form['print_parent_selector'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Print parent selector'),
      '#default_value' => $this->options['print_parent_selector'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($empty = FALSE) {
    $config = $this->options;
    $type = $this->areaType;
    if (!empty($this->view->$type)) {
      $config = $this->view->$type["area_printjs_views"]->options;
    }
    return \Drupal::service('print.js')
      ->getBtnPrintjs($this->options['printText'], $config);
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['printText'] = ['default' => $this->t('Print')];
    $options['print_parent_selector'] = ['default' => ''];
    $options['printjs_id'] = ['default' => ''];
    return $options;
  }

}
